@@ -5,7 +5,7 @@ from django.utils.module_loading import import_string
 DEFAULTS = {
     'FORM_RESPONSE_SAVE': 'django_form_generator.models.save_form_response',
     'FORM_EVALUATIONS': {'form_data': '{{form_data}}'},
-    'MAX_UPLOAD_FILE_SIZE': 5242880,
+    # 'MAX_UPLOAD_FILE_SIZE': 5242880,
     'FORM_GENERATOR_FORM': 'django_form_generator.forms.FormGeneratorForm',
     'FORM_RESPONSE_FORM': 'django_form_generator.forms.FormGeneratorResponseForm',
     'FORM_THEME_CHOICES': 'django_form_generator.const.FormTheme',
